@@ -7,59 +7,40 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
+#include <config-libkleo.h>
+
 #include "enum.h"
-#include "libkleo_debug.h"
-#include "models/keycache.h"
 
-#include <functional>
+#include <libkleo/keycache.h>
+
+#include <libkleo_debug.h>
 
-#include <KLocalizedString>
 #include <KLazyLocalizedString>
+#include <KLocalizedString>
+
+#include <QEventLoop>
+#include <QString>
 
 #include <gpgme++/key.h>
 #include <gpgme++/tofuinfo.h>
 
-#include <QString>
-#include <QEventLoop>
+#include <functional>
 
 static const struct {
     Kleo::CryptoMessageFormat format;
     const KLazyLocalizedString displayName;
     const char *configName;
 } cryptoMessageFormats[] = {
-    {
-        Kleo::InlineOpenPGPFormat,
-        kli18n("Inline OpenPGP (deprecated)"),
-        "inline openpgp"
-    },
-    {
-        Kleo::OpenPGPMIMEFormat,
-        kli18n("OpenPGP/MIME"),
-        "openpgp/mime"
-    },
-    {
-        Kleo::SMIMEFormat,
-        kli18n("S/MIME"),
-        "s/mime"
-    },
-    {
-        Kleo::SMIMEOpaqueFormat,
-        kli18n("S/MIME Opaque"),
-        "s/mime opaque"
-    },
-    {
-        Kleo::AnySMIME,
-        kli18n("Any S/MIME"),
-        "any s/mime"
-    },
-    {
-        Kleo::AnyOpenPGP,
-        kli18n("Any OpenPGP"),
-        "any openpgp"
-    },
+    // clang-format off
+    {Kleo::InlineOpenPGPFormat, kli18n("Inline OpenPGP (deprecated)"), "inline openpgp"},
+    {Kleo::OpenPGPMIMEFormat,   kli18n("OpenPGP/MIME"),                "openpgp/mime"  },
+    {Kleo::SMIMEFormat,         kli18n("S/MIME"),                      "s/mime"        },
+    {Kleo::SMIMEOpaqueFormat,   kli18n("S/MIME Opaque"),               "s/mime opaque" },
+    {Kleo::AnySMIME,            kli18n("Any S/MIME"),                  "any s/mime"    },
+    {Kleo::AnyOpenPGP,          kli18n("Any OpenPGP"),                 "any openpgp"   },
+    // clang-format on
 };
-static const unsigned int numCryptoMessageFormats
-    = sizeof cryptoMessageFormats / sizeof * cryptoMessageFormats;
+static const unsigned int numCryptoMessageFormats = sizeof cryptoMessageFormats / sizeof *cryptoMessageFormats;
 
 const char *Kleo::cryptoMessageFormatToString(Kleo::CryptoMessageFormat f)
 {
@@ -248,7 +229,8 @@ Kleo::TrustLevel Kleo::trustLevel(const GpgME::Key &key)
     return maxTl;
 }
 
-namespace {
+namespace
+{
 
 bool hasTrustedSignature(const GpgME::UserID &uid)
 {
@@ -259,22 +241,21 @@ bool hasTrustedSignature(const GpgME::UserID &uid)
     }
     if (!keyCache->initialized()) {
         QEventLoop el;
-        QObject::connect(keyCache.get(), &Kleo::KeyCache::keyListingDone,
-                         &el, &QEventLoop::quit);
+        QObject::connect(keyCache.get(), &Kleo::KeyCache::keyListingDone, &el, &QEventLoop::quit);
         el.exec();
     }
 
     const auto signatures = uid.signatures();
     std::vector<std::string> sigKeyIDs;
-    std::transform(signatures.cbegin(), signatures.cend(),
+    std::transform(signatures.cbegin(),
+                   signatures.cend(),
                    std::back_inserter(sigKeyIDs),
                    std::bind(&GpgME::UserID::Signature::signerKeyID, std::placeholders::_1));
 
     const auto keys = keyCache->findByKeyIDOrFingerprint(sigKeyIDs);
-    return std::any_of(keys.cbegin(), keys.cend(),
-                       [](const GpgME::Key &key) {
-                           return key.ownerTrust() == GpgME::Key::Ultimate;
-                       });
+    return std::any_of(keys.cbegin(), keys.cend(), [](const GpgME::Key &key) {
+        return key.ownerTrust() == GpgME::Key::Ultimate;
+    });
 }
 
 }
